Install the latest
===================

To install the latest version of izi simply run:

```bash
pip3 install izi --upgrade
```

Ideally, within a virtual environment.


Changelog
=========

### 1.0.0 - Sep 17, 2018
- Fixed issue #631: Added support for Python 3.7
- Fixed issue #665: Fixed problem with izi.types.json
- Fixed issue #679: Return docs for marshmallow schema instead of for dump method
